/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KeyboardLayouts.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef KEYBOARD_LAYOUT_INTERFACE_H
#define KEYBOARD_LAYOUT_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>
#include "layoutnames.h"

/*
 * Proxy class for interface org.kde.KeyboardLayouts
 */
class OrgKdeKeyboardLayoutsInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.KeyboardLayouts"; }

public:
    OrgKdeKeyboardLayoutsInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKeyboardLayoutsInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<uint> getLayout()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("getLayout"), argumentList);
    }

    inline QDBusPendingReply<QList<LayoutNames> > getLayoutsList()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("getLayoutsList"), argumentList);
    }

    inline QDBusPendingReply<bool> setLayout(uint layout)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(layout);
        return asyncCallWithArgumentList(QStringLiteral("setLayout"), argumentList);
    }

    inline QDBusPendingReply<> switchToNextLayout()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("switchToNextLayout"), argumentList);
    }

    inline QDBusPendingReply<> switchToPreviousLayout()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("switchToPreviousLayout"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void layoutChanged(uint layout);
    void layoutListChanged();
};

namespace org {
  namespace kde {
    using KeyboardLayouts = ::OrgKdeKeyboardLayoutsInterface;
  }
}

#endif
