/****************************************************************************
** Meta object code from reading C++ file 'panel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.3/shell/scripting/panel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'panel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18WorkspaceScripting5PanelE_t {};
} // unnamed namespace

template <> constexpr inline auto WorkspaceScripting::Panel::qt_create_metaobjectdata<qt_meta_tag_ZN18WorkspaceScripting5PanelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WorkspaceScripting::Panel",
        "remove",
        "",
        "showConfigurationInterface",
        "configKeys",
        "configGroups",
        "currentConfigGroup",
        "globalConfigKeys",
        "globalConfigGroups",
        "version",
        "type",
        "formFactor",
        "widgetIds",
        "QList<int>",
        "screen",
        "location",
        "id",
        "locked",
        "alignment",
        "offset",
        "lengthMode",
        "length",
        "minimumLength",
        "maximumLength",
        "height",
        "hiding",
        "floating",
        "opacity"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'remove'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showConfigurationInterface'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'configKeys'
        QtMocHelpers::PropertyData<QStringList>(4, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'configGroups'
        QtMocHelpers::PropertyData<QStringList>(5, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'currentConfigGroup'
        QtMocHelpers::PropertyData<QStringList>(6, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'globalConfigKeys'
        QtMocHelpers::PropertyData<QStringList>(7, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'globalConfigGroups'
        QtMocHelpers::PropertyData<QStringList>(8, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'version'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'type'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'formFactor'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'widgetIds'
        QtMocHelpers::PropertyData<QList<int>>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'screen'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'location'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'id'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'locked'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'alignment'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'offset'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'lengthMode'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'length'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'minimumLength'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'maximumLength'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'height'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'hiding'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'floating'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'opacity'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Panel, qt_meta_tag_ZN18WorkspaceScripting5PanelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WorkspaceScripting::Panel::staticMetaObject = { {
    QMetaObject::SuperData::link<Containment::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18WorkspaceScripting5PanelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18WorkspaceScripting5PanelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18WorkspaceScripting5PanelE_t>.metaTypes,
    nullptr
} };

void WorkspaceScripting::Panel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Panel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->remove(); break;
        case 1: _t->showConfigurationInterface(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->configKeys(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->configGroups(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->currentConfigGroup(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->globalConfigKeys(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->globalConfigGroups(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->version(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->type(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->formFactor(); break;
        case 8: *reinterpret_cast<QList<int>*>(_v) = _t->widgetIds(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->screen(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->location(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->id(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->locked(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->alignment(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->offset(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->lengthMode(); break;
        case 16: *reinterpret_cast<int*>(_v) = _t->length(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->minimumLength(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->maximumLength(); break;
        case 19: *reinterpret_cast<int*>(_v) = _t->height(); break;
        case 20: *reinterpret_cast<QString*>(_v) = _t->hiding(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->floating(); break;
        case 22: *reinterpret_cast<QString*>(_v) = _t->opacity(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setCurrentConfigGroup(*reinterpret_cast<QStringList*>(_v)); break;
        case 9: _t->setScreen(*reinterpret_cast<int*>(_v)); break;
        case 10: _t->setLocation(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setLocked(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setAlignment(*reinterpret_cast<QString*>(_v)); break;
        case 14: _t->setOffset(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setLengthMode(*reinterpret_cast<QString*>(_v)); break;
        case 16: _t->setLength(*reinterpret_cast<int*>(_v)); break;
        case 17: _t->setMinimumLength(*reinterpret_cast<int*>(_v)); break;
        case 18: _t->setMaximumLength(*reinterpret_cast<int*>(_v)); break;
        case 19: _t->setHeight(*reinterpret_cast<int*>(_v)); break;
        case 20: _t->setHiding(*reinterpret_cast<QString*>(_v)); break;
        case 21: _t->setFloating(*reinterpret_cast<bool*>(_v)); break;
        case 22: _t->setOpacity(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *WorkspaceScripting::Panel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WorkspaceScripting::Panel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18WorkspaceScripting5PanelE_t>.strings))
        return static_cast<void*>(this);
    return Containment::qt_metacast(_clname);
}

int WorkspaceScripting::Panel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Containment::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    return _id;
}
QT_WARNING_POP
