/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KSMServerInterface.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef KSMSERVER_INTERFACE_H
#define KSMSERVER_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.KSMServerInterface
 */
class OrgKdeKSMServerInterfaceInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.KSMServerInterface"; }

public:
    OrgKdeKSMServerInterfaceInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKSMServerInterfaceInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<bool> closeSession()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("closeSession"), argumentList);
    }

    inline QDBusPendingReply<QString> currentSession()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("currentSession"), argumentList);
    }

    inline QDBusPendingReply<bool> isShuttingDown()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("isShuttingDown"), argumentList);
    }

    inline QDBusPendingReply<> resetLogout()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("resetLogout"), argumentList);
    }

    inline QDBusPendingReply<> restoreSession()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("restoreSession"), argumentList);
    }

    inline QDBusPendingReply<> saveCurrentSession()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("saveCurrentSession"), argumentList);
    }

    inline QDBusPendingReply<> saveCurrentSessionAs(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("saveCurrentSessionAs"), argumentList);
    }

    inline QDBusPendingReply<QStringList> sessionList()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("sessionList"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace kde {
    using KSMServerInterface = ::OrgKdeKSMServerInterfaceInterface;
  }
}

#endif
