/****************************************************************************
** Meta object code from reading C++ file 'menuimporter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.3/appmenu/menuimporter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'menuimporter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12MenuImporterE_t {};
} // unnamed namespace

template <> constexpr inline auto MenuImporter::qt_create_metaobjectdata<qt_meta_tag_ZN12MenuImporterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MenuImporter",
        "WindowRegistered",
        "",
        "WId",
        "id",
        "service",
        "QDBusObjectPath",
        "WindowUnregistered",
        "RegisterWindow",
        "Q_NOREPLY",
        "path",
        "UnregisterWindow",
        "GetMenuForWindow",
        "QDBusObjectPath&",
        "slotServiceUnregistered"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'WindowRegistered'
        QtMocHelpers::SignalData<void(WId, const QString &, const QDBusObjectPath &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 2 },
        }}),
        // Signal 'WindowUnregistered'
        QtMocHelpers::SignalData<void(WId)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'RegisterWindow'
        QtMocHelpers::SlotData<void(WId, const QDBusObjectPath &)>(8, 9, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 6, 10 },
        }}),
        // Slot 'UnregisterWindow'
        QtMocHelpers::SlotData<void(WId)>(11, 9, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'GetMenuForWindow'
        QtMocHelpers::SlotData<QString(WId, QDBusObjectPath &)>(12, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 13, 10 },
        }}),
        // Slot 'slotServiceUnregistered'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MenuImporter, qt_meta_tag_ZN12MenuImporterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MenuImporter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12MenuImporterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12MenuImporterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12MenuImporterE_t>.metaTypes,
    nullptr
} };

void MenuImporter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MenuImporter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->WindowRegistered((*reinterpret_cast<std::add_pointer_t<WId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[3]))); break;
        case 1: _t->WindowUnregistered((*reinterpret_cast<std::add_pointer_t<WId>>(_a[1]))); break;
        case 2: _t->RegisterWindow((*reinterpret_cast<std::add_pointer_t<WId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 3: _t->UnregisterWindow((*reinterpret_cast<std::add_pointer_t<WId>>(_a[1]))); break;
        case 4: { QString _r = _t->GetMenuForWindow((*reinterpret_cast<std::add_pointer_t<WId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath&>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->slotServiceUnregistered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MenuImporter::*)(WId , const QString & , const QDBusObjectPath & )>(_a, &MenuImporter::WindowRegistered, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MenuImporter::*)(WId )>(_a, &MenuImporter::WindowUnregistered, 1))
            return;
    }
}

const QMetaObject *MenuImporter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MenuImporter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12MenuImporterE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int MenuImporter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void MenuImporter::WindowRegistered(WId _t1, const QString & _t2, const QDBusObjectPath & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void MenuImporter::WindowUnregistered(WId _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
